@@ -35,11 +35,26 @@ test_that("testing adding EQ5D5L values to the data", {
   expect_error(value_eq5d5L_IPD(trial_data, NA))
   # Error - data should not be NULL
   expect_error(value_eq5d5L_IPD(NULL, NA))
-  trialdatafile <- system.file("extdata", "trial_data_sampleEq5d.csv", package = "packDAMipd")
+  trialdatafile <- system.file("extdata", "trial_data_sampleEq5d.csv",
+                               package = "packDAMipd")
   trial_data <- read.csv(trialdatafile)
   results <- value_eq5d5L_IPD(trial_data, NA)
   expect_equal(results$EQ5D5LIndex[1], 0.535)
 
+  trial_data <- data.frame(
+    "qol.MO" = c(1, 3, NA), "qol.SC" = c(1, 3, 1), "qol.UA" = c(1, 1, 1),
+    "qol.PD" = c(3, 2, 1), "qol.AD" = c(2, 2, 1)
+  )
+  results <- value_eq5d5L_IPD(trial_data, NA)
+  expect_equal(results$EQ5D5LIndex, c(0.838, 0.703, NA))
+
+  trial_data <- data.frame(
+    "qol.MO" = c(1, 3, 99), "qol.SC" = c(1, 3, 1), "qol.UA" = c(1, 1, 1),
+    "qol.PD" = c(3, 2, 1), "qol.AD" = c(2, 2, 1)
+  )
+  results <- value_eq5d5L_IPD(trial_data, 99)
+  expect_equal(results$EQ5D5LIndex, c(0.838, 0.703, 99))
+
 })
 ###############################################################################
 context("testing adding EQ5D3L values to the data")
@@ -62,10 +77,24 @@ test_that("testing adding EQ5D3L values to the data", {
   expect_error(value_eq5d3L_IPD(trial_data, NA))
   # Error - data should not be NULL
   expect_error(value_eq5d3L_IPD(NULL, NA))
-  trialdatafile <- system.file("extdata", "trial_data_sampleEq5d3l.csv", package = "packDAMipd")
+  trialdatafile <- system.file("extdata", "trial_data_sampleEq5d3l.csv",
+                               package = "packDAMipd")
   trial_data <- read.csv(trialdatafile)
   results <- value_eq5d3L_IPD(trial_data, NA)
   expect_equal(results$EQ5D3LIndex[1], 0.014)
+  trial_data <- data.frame(
+    "qol.MO" = c(1, 3, NA), "qol.SC" = c(1, 3, 1), "qol.UA" = c(1, 1, 1),
+    "qol.PD" = c(3, 2, 1), "qol.AD" = c(2, 2, 1)
+  )
+  results <- value_eq5d3L_IPD(trial_data, NA)
+  expect_equal(results$EQ5D3LIndex, c(0.193, -0.072, NA))
+
+  trial_data <- data.frame(
+    "qol.MO" = c(1, 3, 99), "qol.SC" = c(1, 3, 1), "qol.UA" = c(1, 1, 1),
+    "qol.PD" = c(3, 2, 1), "qol.AD" = c(2, 2, 1)
+  )
+  results <- value_eq5d3L_IPD(trial_data, 99)
+  expect_equal(results$EQ5D3LIndex, c(0.193, -0.072, 99))
 
 })
 ###############################################################################
@@ -92,11 +121,25 @@ test_that("testing adding EQ5D5L values to the data", {
   trial_data <- read.csv(trialdatafile)
   results <- map_eq5d5Lto3L_VanHout(trial_data, NA)
   expect_equal(results$EQ5D3L_from5L[1], 0.1311, tol = 1e-4)
+
+  trial_data <- data.frame(
+    "qol.MO" = c(1, 2, NA), "qol.SC" = c(1, 2, 3), "qol.UA" = c(1, 2, 3),
+    "qol.PD" = c(1, 2, 3), "qol.AD" = c(1, 2, 3)
+  )
+  results <- map_eq5d5Lto3L_VanHout(trial_data, NA)
+  expect_equal(results$EQ5D3L_from5L, c(1, 0.5919117, NA))
+
+  trial_data <- data.frame(
+    "qol.MO" = c(1, 2, -99), "qol.SC" = c(1, 2, 3), "qol.UA" = c(1, 2, 3),
+    "qol.PD" = c(1, 2, 3), "qol.AD" = c(1, 2, 3)
+  )
+  results <- map_eq5d5Lto3L_VanHout(trial_data,-99)
+  expect_equal(results$EQ5D3L_from5L, c(1, 0.5919117, -99))
 })
 ##############################################################################
 
-context("testing conversion of ADL responses to scores ")
-test_that("testing adding EQ5D5L values to the data", {
+context("testing conversion of ADL responses to scores")
+test_that("testing conversion of ADL responses to scores", {
   trial_data <- data.frame(
     "tpi.q1" = c(1, 2), "tpi.q2" = c(1, 2), "tpi.q3" = c(1, 2),
     "tpi.q4" = c(1, 2),
@@ -104,7 +147,7 @@ test_that("testing adding EQ5D5L values to the data", {
     "tpi.q8" = c(1, 2)
   )
 
-  results <- value_ADL_scores_IPD(trial_data, c("tpi"), adl_scoring, NA)
+  results <- value_ADL_scores_IPD(trial_data, c("tpi"), NA, adl_scoring)
   expect_equal(results$ADLTscore, c(40.7, 55.8))
   this_data <- data.table::data.table("Age" = c("k", 15), "sex" = c("m", "f"))
   expect_error(value_ADL_scores_IPD(this_data, NA, NA, NA))
@@ -112,33 +155,59 @@ test_that("testing adding EQ5D5L values to the data", {
     "qol.MO" = c(1, 2), "qol.SC" = c(1, 8), "qol.UA" = c(1, 2),
     "qol.PD" = c(1, 2), "qol.AD" = c(1, 2)
   )
-  expect_error(value_ADL_scores_IPD(trial_data, adl_scoring, NA, NA))
+  expect_error(value_ADL_scores_IPD(trial_data, NA, NA))
   #Error data should not be NULL
-  expect_error(value_ADL_scores_IPD(NULL, adl_scoring, NA, NA))
-  #Error adl scoring table
-  expect_error(value_ADL_scores_IPD(trial_data, c("tpi"), NULL, NA))
+  expect_error(value_ADL_scores_IPD(NULL, c("tpi"), NA, adl_scoring))
 
   #Error no matching columns
-  expect_error(value_ADL_scores_IPD(trial_data, NULL, adl_scoring, NA))
+  expect_error(value_ADL_scores_IPD(trial_data, NULL, NA, adl_scoring))
 
   trialdatafile <- system.file("extdata", "trial_data_sampleEq5d.csv",
                                package = "packDAMipd")
   trial_data <- read.csv(trialdatafile)
-  results <- value_ADL_scores_IPD(trial_data, c("tpi"), adl_scoring, NA)
+
+  results <- value_ADL_scores_IPD(trial_data, c("tpi"), NA, NULL )
   expect_equal(results$ADLTscore[1], 60.2, tol = 1e-4)
 
   trialdatafile <- system.file("extdata", "trial_data_sample_notenoughcol.csv",
                                package = "packDAMipd")
   trial_data <- read.csv(trialdatafile)
   # Error - ADL should have  columns
-  expect_error(value_ADL_scores_IPD(trial_data, c("tpi"), adl_scoring, NA))
+  expect_error(value_ADL_scores_IPD(trial_data, c("tpi"),NA, adl_scoring))
 
   trialdatafile <- system.file("extdata", "trial_data_sample_error.csv",
                                package = "packDAMipd")
   trial_data <- read.csv(trialdatafile)
   # Error - ADL responses do not seem right
-  expect_error(value_ADL_scores_IPD(trial_data, c("tpi"), adl_scoring, NA))
+  expect_error(value_ADL_scores_IPD(trial_data, c("tpi"), NA, adl_scoring))
 
+  trial_data <- data.frame(
+    "tpi.q1" = c(1, 2,3), "tpi.q2" = c(1, 2, 3), "tpi.q3" = c(1, 2, 3),
+    "tpi.q4" = c(1, 2,3),
+    "tpi.q5" = c(1, 2, 3), "tpi.q6" = c(1, 2, NA), "tpi.q7" = c(1, 2, 3),
+    "tpi.q8" = c(1, 2, NA)
+  )
+  results <- value_ADL_scores_IPD(trial_data, c("tpi"), NA, NULL)
+  expect_equal(results$ADLTscore, c(40.7, 55.8, NA))
+
+  trial_data <- data.frame(
+    "tpi.q1" = c(1, NA, 3, 4), "tpi.q2" = c(1, 2, 3, 4), "tpi.q3" = c(1, 2, 3, 4),
+    "tpi.q4" = c(1, 2, 3, 4),
+    "tpi.q5" = c(1, 2, 3, 4), "tpi.q6" = c(1, 2, NA, 4), "tpi.q7" = c(1, 2, 3, 4),
+    "tpi.q8" = c(1, 2, 3, 4)
+  )
+  results <- value_ADL_scores_IPD(trial_data, c("tpi"), NA, NULL)
+  expect_equal(results$ADLTscore, c(40.7, NA, NA, 66.9))
+
+
+  trial_data <- data.frame(
+    "tpi.q1" = c(1, -99, 3, 4), "tpi.q2" = c(1, 2, 3, 4), "tpi.q3" = c(1, 2, 3, 4),
+    "tpi.q4" = c(1, 2, 3, 4),
+    "tpi.q5" = c(1, 2, 3, 4), "tpi.q6" = c(1, 2, -99, 4), "tpi.q7" = c(1, 2, 3, 4),
+    "tpi.q8" = c(1, 2, 3, 4)
+  )
+  results <- value_ADL_scores_IPD(trial_data, c("tpi"), -99, NULL)
+  expect_equal(results$ADLTscore, c(40.7, -99, -99, 66.9))
 })
 ###############################################################################
 
@@ -179,6 +248,22 @@ test_that("testing adding EQ5D5L values to the data", {
   trial_data <- read.csv(trialdatafile)
   # Error - shows responses do not seem right
   expect_error(value_Shows_IPD(trial_data, c("qsy"), NA))
+  trial_data <- data.frame(
+    "shows.q1" = c(1, 2,3), "shows.q2" = c(1, 2, NA), "shows.q3" = c(1, 2, 3),
+    "shows.q4" = c(1, 2, 3), "shows.q5" = c(1, 2, 3), "shows.q6" = c(1, 2, 3),
+    "shows.q7" = c(1, 2, 3), "shows.q8" = c(1, 2, 3), "shows.q9" = c(1, 2, 3),
+    "shows.q10" = c(1, 2, 3)
+  )
+  results <- value_Shows_IPD(trial_data, c("shows"), NA)
+  expect_equal(results$ShOWSscore, c(0, 10, NA))
 
+  trial_data <- data.frame(
+    "shows.q1" = c(1, 2,3), "shows.q2" = c(1, 2, -99), "shows.q3" = c(1, 2, 3),
+    "shows.q4" = c(1, 2, 3), "shows.q5" = c(1, 2, 3), "shows.q6" = c(1, 2, 3),
+    "shows.q7" = c(1, 2, 3), "shows.q8" = c(1, 2, 3), "shows.q9" = c(1, 2, 3),
+    "shows.q10" = c(1, 2, 3)
+  )
+  results <- value_Shows_IPD(trial_data, c("shows"), -99)
+  expect_equal(results$ShOWSscore, c(0, 10, -99))
 
 })
